@@ -173,8 +173,6 @@ class CameraModelForm(ModelForm):
                             'groups',
                             AppendedText('nominal_min_angle_diag', '&deg;'),
                             AppendedText('nominal_max_angle_diag', '&deg;'),
-                            'rectilinear',
-                            AppendedText('image_circle', 'mm'),
                             'aperture_blades',
                             'coating',
                             AppendedText('magnification', '&times;'),
@@ -214,7 +212,8 @@ class CameraModelForm(ModelForm):
                 'Shutter',
                 'shutter_type',
                 'shutter_model',
-                InlineCheckboxes('shutter_speeds'),
+                'fastest_shutter_speed',
+                'slowest_shutter_speed',
                 'bulb',
                 'time',
             ),
@@ -240,6 +239,7 @@ class CameraModelForm(ModelForm):
                 'mirror_lockup',
                 'tripod',
                 'self_timer',
+                'date_imprint',
                 'power_drive',
                 AppendedText('continuous_fps', 'fps'),
             ),
@@ -465,7 +465,6 @@ class LensModelForm(ModelForm):
                 AppendedText('nominal_min_angle_diag', '&deg;'),
                 AppendedText('nominal_max_angle_diag', '&deg;'),
                 'lens_type',
-                'rectilinear',
                 AppendedText('image_circle', 'mm'),
                 'aperture_blades',
                 'coating',
